@@ -16,14 +16,14 @@ DEBUG_INIT("network");
 int le_libvirt_network;
 
 void
-php_libvirt_network_dtor(virt_resource *rsrc TSRMLS_DC)
+php_libvirt_network_dtor(zend_resource *rsrc)
 {
     php_libvirt_network *network = (php_libvirt_network *)rsrc->ptr;
     int rv = 0;
 
     if (network != NULL) {
         if (network->network != NULL) {
-            if (!check_resource_allocation(network->conn->conn, INT_RESOURCE_NETWORK, network->network TSRMLS_CC)) {
+            if (!check_resource_allocation(network->conn->conn, INT_RESOURCE_NETWORK, network->network)) {
                 network->network = NULL;
                 efree(network);
                 return;
@@ -31,10 +31,10 @@ php_libvirt_network_dtor(virt_resource *rsrc TSRMLS_DC)
             rv = virNetworkFree(network->network);
             if (rv != 0) {
                 DPRINTF("%s: virNetworkFree(%p) returned %d (%s)\n", __FUNCTION__, network->network, rv, LIBVIRT_G(last_error));
-                php_error_docref(NULL TSRMLS_CC, E_WARNING, "virStorageVolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
+                php_error_docref(NULL, E_WARNING, "virStorageVolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
             } else {
                 DPRINTF("%s: virNetworkFree(%p) completed successfully\n", __FUNCTION__, network->network);
-                resource_change_counter(INT_RESOURCE_NETWORK, network->conn->conn, network->network, 0 TSRMLS_CC);
+                resource_change_counter(INT_RESOURCE_NETWORK, network->conn->conn, network->network, 0);
             }
             network->network = NULL;
         }
@@ -57,12 +57,12 @@ PHP_FUNCTION(libvirt_network_define_xml)
     virNetwork *net;
     zval *zconn;
     char *xml = NULL;
-    strsize_t xml_len;
+    size_t xml_len;
 
     GET_CONNECTION_FROM_ARGS("rs", &zconn, &xml, &xml_len);
 
     if ((net = virNetworkDefineXML(conn->conn, xml)) == NULL) {
-        set_error_if_unset("Cannot define a new network" TSRMLS_CC);
+        set_error_if_unset("Cannot define a new network");
         RETURN_FALSE;
     }
 
@@ -71,7 +71,7 @@ PHP_FUNCTION(libvirt_network_define_xml)
     res_net->conn = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_net->network);
-    resource_change_counter(INT_RESOURCE_NETWORK, conn->conn, res_net->network, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_NETWORK, conn->conn, res_net->network, 1);
 
     VIRT_REGISTER_RESOURCE(res_net, le_libvirt_network);
 }
@@ -91,7 +91,7 @@ PHP_FUNCTION(libvirt_network_get_xml_desc)
     char *xml = NULL;
     char *xpath = NULL;
     char *tmp;
-    strsize_t xpath_len;
+    size_t xpath_len;
     int retval = -1;
 
     GET_NETWORK_FROM_ARGS("r|s", &znetwork, &xpath, &xpath_len);
@@ -101,7 +101,7 @@ PHP_FUNCTION(libvirt_network_get_xml_desc)
     xml = virNetworkGetXMLDesc(network->network, 0);
 
     if (xml == NULL) {
-        set_error_if_unset("Cannot get network XML" TSRMLS_CC);
+        set_error_if_unset("Cannot get network XML");
         RETURN_FALSE;
     }
 
@@ -151,12 +151,12 @@ PHP_FUNCTION(libvirt_network_get)
     virNetwork *net;
     zval *zconn;
     char *name;
-    strsize_t name_len;
+    size_t name_len;
 
     GET_CONNECTION_FROM_ARGS("rs", &zconn, &name, &name_len);
 
     if ((net = virNetworkLookupByName(conn->conn, name)) == NULL) {
-        set_error_if_unset("Cannot get find requested network" TSRMLS_CC);
+        set_error_if_unset("Cannot get find requested network");
         RETURN_FALSE;
     }
 
@@ -165,7 +165,7 @@ PHP_FUNCTION(libvirt_network_get)
     res_net->conn = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_net->network);
-    resource_change_counter(INT_RESOURCE_NETWORK, conn->conn, res_net->network, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_NETWORK, conn->conn, res_net->network, 1);
 
     VIRT_REGISTER_RESOURCE(res_net, le_libvirt_network);
 }
@@ -188,7 +188,7 @@ PHP_FUNCTION(libvirt_network_get_bridge)
     name = virNetworkGetBridgeName(network->network);
 
     if (name == NULL) {
-        set_error_if_unset("Cannot get network bridge name" TSRMLS_CC);
+        set_error_if_unset("Cannot get network bridge name");
         RETURN_FALSE;
     }
 
@@ -214,7 +214,7 @@ PHP_FUNCTION(libvirt_network_get_active)
     res = virNetworkIsActive(network->network);
 
     if (res == -1) {
-        set_error_if_unset("Error getting virtual network state" TSRMLS_CC);
+        set_error_if_unset("Error getting virtual network state");
         RETURN_FALSE;
     }
 
@@ -240,7 +240,7 @@ PHP_FUNCTION(libvirt_network_set_active)
     GET_NETWORK_FROM_ARGS("rl", &znetwork, &act);
 
     if ((act != 0) && (act != 1)) {
-        set_error("Invalid network activity state" TSRMLS_CC);
+        set_error("Invalid network activity state");
         RETURN_FALSE;
     }
 
@@ -292,7 +292,7 @@ PHP_FUNCTION(libvirt_network_get_information)
     xml = virNetworkGetXMLDesc(network->network, 0);
 
     if (xml == NULL) {
-        set_error_if_unset("Cannot get network XML" TSRMLS_CC);
+        set_error_if_unset("Cannot get network XML");
         RETURN_FALSE;
     }
 
@@ -301,12 +301,12 @@ PHP_FUNCTION(libvirt_network_get_information)
     /* Get name */
     name = get_string_from_xpath(xml, "//network/name", NULL, &retval);
     if (name == NULL) {
-        set_error("Invalid XPath node for network name" TSRMLS_CC);
+        set_error("Invalid XPath node for network name");
         RETURN_FALSE;
     }
 
     if (retval < 0) {
-        set_error("Cannot get XPath expression result for network name" TSRMLS_CC);
+        set_error("Cannot get XPath expression result for network name");
         RETURN_FALSE;
     }
 
@@ -522,7 +522,7 @@ PHP_FUNCTION(libvirt_list_all_networks)
 
         VIRT_REGISTER_LIST_RESOURCE(network);
         resource_change_counter(INT_RESOURCE_NETWORK, conn->conn,
-                                res_network->network, 1 TSRMLS_CC);
+                                res_network->network, 1);
     }
 }
 
@@ -587,7 +587,7 @@ PHP_FUNCTION(libvirt_network_get_dhcp_leases)
     php_libvirt_network *network = NULL;
     zval *znetwork;
     char *mac = NULL;
-    strsize_t mac_len;
+    size_t mac_len;
     zend_long flags = 0;
 
     virNetworkDHCPLeasePtr *leases = NULL;
@@ -600,7 +600,7 @@ PHP_FUNCTION(libvirt_network_get_dhcp_leases)
     GET_NETWORK_FROM_ARGS("r|sl", &znetwork, &mac, &mac_len, &flags);
 
     if ((nleases = virNetworkGetDHCPLeases(network->network, mac, &leases, flags)) < 0) {
-        set_error_if_unset("Failed to get leases info" TSRMLS_CC);
+        set_error_if_unset("Failed to get leases info");
         goto cleanup;
     }
 
