@@ -19,14 +19,14 @@ int le_libvirt_storagepool;
 int le_libvirt_volume;
 
 void
-php_libvirt_storagepool_dtor(virt_resource *rsrc TSRMLS_DC)
+php_libvirt_storagepool_dtor(zend_resource *rsrc)
 {
     php_libvirt_storagepool *pool = (php_libvirt_storagepool *)rsrc->ptr;
     int rv = 0;
 
     if (pool != NULL) {
         if (pool->pool != NULL) {
-            if (!check_resource_allocation(NULL, INT_RESOURCE_STORAGEPOOL, pool->pool TSRMLS_CC)) {
+            if (!check_resource_allocation(NULL, INT_RESOURCE_STORAGEPOOL, pool->pool)) {
                 pool->pool = NULL;
                 efree(pool);
                 return;
@@ -34,10 +34,10 @@ php_libvirt_storagepool_dtor(virt_resource *rsrc TSRMLS_DC)
             rv = virStoragePoolFree(pool->pool);
             if (rv != 0) {
                 DPRINTF("%s: virStoragePoolFree(%p) returned %d (%s)\n", __FUNCTION__, pool->pool, rv, LIBVIRT_G(last_error));
-                php_error_docref(NULL TSRMLS_CC, E_WARNING, "virStoragePoolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
+                php_error_docref(NULL, E_WARNING, "virStoragePoolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
             } else {
                 DPRINTF("%s: virStoragePoolFree(%p) completed successfully\n", __FUNCTION__, pool->pool);
-                resource_change_counter(INT_RESOURCE_STORAGEPOOL, pool->conn->conn, pool->pool, 0 TSRMLS_CC);
+                resource_change_counter(INT_RESOURCE_STORAGEPOOL, pool->conn->conn, pool->pool, 0);
             }
             pool->pool = NULL;
         }
@@ -46,14 +46,14 @@ php_libvirt_storagepool_dtor(virt_resource *rsrc TSRMLS_DC)
 }
 
 void
-php_libvirt_volume_dtor(virt_resource *rsrc TSRMLS_DC)
+php_libvirt_volume_dtor(zend_resource *rsrc)
 {
     php_libvirt_volume *volume = (php_libvirt_volume *)rsrc->ptr;
     int rv = 0;
 
     if (volume != NULL) {
         if (volume->volume != NULL) {
-            if (!check_resource_allocation(NULL, INT_RESOURCE_VOLUME, volume->volume TSRMLS_CC)) {
+            if (!check_resource_allocation(NULL, INT_RESOURCE_VOLUME, volume->volume)) {
                 volume->volume = NULL;
                 efree(volume);
                 return;
@@ -61,10 +61,10 @@ php_libvirt_volume_dtor(virt_resource *rsrc TSRMLS_DC)
             rv = virStorageVolFree(volume->volume);
             if (rv != 0) {
                 DPRINTF("%s: virStorageVolFree(%p) returned %d (%s)\n", __FUNCTION__, volume->volume, rv, LIBVIRT_G(last_error));
-                php_error_docref(NULL TSRMLS_CC, E_WARNING, "virStorageVolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
+                php_error_docref(NULL, E_WARNING, "virStorageVolFree failed with %i on destructor: %s", rv, LIBVIRT_G(last_error));
             } else {
                 DPRINTF("%s: virStorageVolFree(%p) completed successfully\n", __FUNCTION__, volume->volume);
-                resource_change_counter(INT_RESOURCE_VOLUME, volume->conn->conn, volume->volume, 0 TSRMLS_CC);
+                resource_change_counter(INT_RESOURCE_VOLUME, volume->conn->conn, volume->volume, 0);
             }
             volume->volume = NULL;
         }
@@ -84,7 +84,7 @@ PHP_FUNCTION(libvirt_storagepool_lookup_by_name)
 {
     php_libvirt_connection *conn = NULL;
     zval *zconn;
-    strsize_t name_len;
+    size_t name_len;
     char *name = NULL;
     virStoragePoolPtr pool = NULL;
     php_libvirt_storagepool *res_pool;
@@ -103,7 +103,7 @@ PHP_FUNCTION(libvirt_storagepool_lookup_by_name)
     res_pool->conn = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_pool->pool);
-    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1);
 
     VIRT_REGISTER_RESOURCE(res_pool, le_libvirt_storagepool);
 }
@@ -134,7 +134,7 @@ PHP_FUNCTION(libvirt_storagepool_lookup_by_volume)
     res_pool->conn = volume->conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_pool->pool);
-    resource_change_counter(INT_RESOURCE_STORAGEPOOL, res_pool->conn->conn, res_pool->pool, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_STORAGEPOOL, res_pool->conn->conn, res_pool->pool, 1);
 
     VIRT_REGISTER_RESOURCE(res_pool, le_libvirt_storagepool);
 }
@@ -201,7 +201,6 @@ PHP_FUNCTION(libvirt_storagepool_get_info)
     array_init(return_value);
 
     // @todo: fix the long long returns
-    LONGLONG_INIT;
     add_assoc_long(return_value, "state", (long)poolInfo.state);
     LONGLONG_ASSOC(return_value, "capacity", poolInfo.capacity);
     LONGLONG_ASSOC(return_value, "allocation", poolInfo.allocation);
@@ -270,7 +269,7 @@ PHP_FUNCTION(libvirt_storagepool_lookup_by_uuid_string)
     php_libvirt_connection *conn = NULL;
     zval *zconn;
     char *uuid = NULL;
-    strsize_t uuid_len;
+    size_t uuid_len;
     virStoragePoolPtr storage = NULL;
     php_libvirt_storagepool *res_pool;
 
@@ -289,7 +288,7 @@ PHP_FUNCTION(libvirt_storagepool_lookup_by_uuid_string)
     res_pool->conn = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_pool->pool);
-    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1);
 
     VIRT_REGISTER_RESOURCE(res_pool, le_libvirt_storagepool);
 }
@@ -310,7 +309,7 @@ PHP_FUNCTION(libvirt_storagepool_get_xml_desc)
     char *xpath = NULL;
     char *tmp = NULL;
     zend_long flags = 0;
-    strsize_t xpath_len;
+    size_t xpath_len;
     int retval = -1;
 
     GET_STORAGEPOOL_FROM_ARGS("r|s", &zpool, &xpath, &xpath_len, &flags);
@@ -321,7 +320,7 @@ PHP_FUNCTION(libvirt_storagepool_get_xml_desc)
 
     xml = virStoragePoolGetXMLDesc(pool->pool, flags);
     if (xml == NULL) {
-        set_error_if_unset("Cannot get the XML description" TSRMLS_CC);
+        set_error_if_unset("Cannot get the XML description");
         RETURN_FALSE;
     }
 
@@ -352,7 +351,7 @@ PHP_FUNCTION(libvirt_storagepool_define_xml)
     zval *zconn;
     virStoragePoolPtr pool = NULL;
     char *xml;
-    strsize_t xml_len;
+    size_t xml_len;
     zend_long flags = 0;
 
 
@@ -368,7 +367,7 @@ PHP_FUNCTION(libvirt_storagepool_define_xml)
     res_pool->conn = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_pool->pool);
-    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_STORAGEPOOL, conn->conn, res_pool->pool, 1);
 
     VIRT_REGISTER_RESOURCE(res_pool, le_libvirt_storagepool);
 }
@@ -605,7 +604,7 @@ PHP_FUNCTION(libvirt_storagevolume_lookup_by_name)
     php_libvirt_storagepool *pool = NULL;
     php_libvirt_volume *res_volume;
     zval *zpool;
-    strsize_t name_len;
+    size_t name_len;
     char *name = NULL;
     virStorageVolPtr volume = NULL;
 
@@ -623,7 +622,7 @@ PHP_FUNCTION(libvirt_storagevolume_lookup_by_name)
     res_volume->conn   = pool->conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_volume->volume);
-    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1);
 
     VIRT_REGISTER_RESOURCE(res_volume, le_libvirt_volume);
 }
@@ -641,7 +640,7 @@ PHP_FUNCTION(libvirt_storagevolume_lookup_by_path)
     php_libvirt_connection *conn = NULL;
     php_libvirt_volume *res_volume;
     zval *zconn;
-    strsize_t name_len;
+    size_t name_len;
     char *name = NULL;
     virStorageVolPtr volume = NULL;
 
@@ -652,7 +651,7 @@ PHP_FUNCTION(libvirt_storagevolume_lookup_by_path)
     volume = virStorageVolLookupByPath(conn->conn, name);
     DPRINTF("%s: virStorageVolLookupByPath(%p, %s) returned %p\n", PHPFUNC, conn->conn, name, volume);
     if (volume == NULL) {
-        set_error_if_unset("Cannot find storage volume on requested path" TSRMLS_CC);
+        set_error_if_unset("Cannot find storage volume on requested path");
         RETURN_FALSE;
     }
 
@@ -661,7 +660,7 @@ PHP_FUNCTION(libvirt_storagevolume_lookup_by_path)
     res_volume->conn   = conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_volume->volume);
-    resource_change_counter(INT_RESOURCE_VOLUME, conn->conn, res_volume->volume, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_VOLUME, conn->conn, res_volume->volume, 1);
 
     VIRT_REGISTER_RESOURCE(res_volume, le_libvirt_volume);
 }
@@ -735,7 +734,6 @@ PHP_FUNCTION(libvirt_storagevolume_get_info)
         RETURN_FALSE;
 
     array_init(return_value);
-    LONGLONG_INIT;
     add_assoc_long(return_value, "type", (long)volumeInfo.type);
     LONGLONG_ASSOC(return_value, "capacity", volumeInfo.capacity);
     LONGLONG_ASSOC(return_value, "allocation", volumeInfo.allocation);
@@ -757,7 +755,7 @@ PHP_FUNCTION(libvirt_storagevolume_get_xml_desc)
     char *tmp = NULL;
     char *xml;
     char *xpath = NULL;
-    strsize_t xpath_len;
+    size_t xpath_len;
     zend_long flags = 0;
     int retval = -1;
 
@@ -769,7 +767,7 @@ PHP_FUNCTION(libvirt_storagevolume_get_xml_desc)
 
     xml = virStorageVolGetXMLDesc(volume->volume, flags);
     if (xml == NULL) {
-        set_error_if_unset("Cannot get the XML description" TSRMLS_CC);
+        set_error_if_unset("Cannot get the XML description");
         RETURN_FALSE;
     }
 
@@ -801,7 +799,7 @@ PHP_FUNCTION(libvirt_storagevolume_create_xml)
     virStorageVolPtr volume = NULL;
     char *xml;
     zend_long flags = 0;
-    strsize_t xml_len;
+    size_t xml_len;
 
     GET_STORAGEPOOL_FROM_ARGS("rs|l", &zpool, &xml, &xml_len, &flags);
 
@@ -815,7 +813,7 @@ PHP_FUNCTION(libvirt_storagevolume_create_xml)
     res_volume->conn   = pool->conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_volume->volume);
-    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1);
 
     VIRT_REGISTER_RESOURCE(res_volume, le_libvirt_volume);
 }
@@ -840,10 +838,10 @@ PHP_FUNCTION(libvirt_storagevolume_create_xml_from)
 
     virStorageVolPtr volume = NULL;
     char *xml;
-    strsize_t xml_len;
+    size_t xml_len;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rsr", &zpool, &xml, &xml_len, &zvolume) == FAILURE) {
-        set_error("Invalid pool resource, XML or volume resource" TSRMLS_CC);
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "rsr", &zpool, &xml, &xml_len, &zvolume) == FAILURE) {
+        set_error("Invalid pool resource, XML or volume resource");
         RETURN_FALSE;
     }
 
@@ -853,7 +851,7 @@ PHP_FUNCTION(libvirt_storagevolume_create_xml_from)
     VIRT_FETCH_RESOURCE(pl_volume, php_libvirt_volume*, &zvolume, PHP_LIBVIRT_VOLUME_RES_NAME, le_libvirt_volume);
     if ((pl_volume == NULL) || (pl_volume->volume == NULL))
         RETURN_FALSE;
-    resource_change_counter(INT_RESOURCE_VOLUME, pl_volume->conn->conn, pl_volume->volume, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_VOLUME, pl_volume->conn->conn, pl_volume->volume, 1);
 
     volume = virStorageVolCreateXMLFrom(pool->pool, xml, pl_volume->volume, 0);
     DPRINTF("%s: virStorageVolCreateXMLFrom(%p, <xml>, %p, 0) returned %p\n", PHPFUNC, pool->pool, pl_volume->volume, volume);
@@ -865,7 +863,7 @@ PHP_FUNCTION(libvirt_storagevolume_create_xml_from)
     res_volume->conn   = pool->conn;
 
     DPRINTF("%s: returning %p\n", PHPFUNC, res_volume->volume);
-    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1 TSRMLS_CC);
+    resource_change_counter(INT_RESOURCE_VOLUME, pool->conn->conn, res_volume->volume, 1);
 
     VIRT_REGISTER_RESOURCE(res_volume, le_libvirt_volume);
 }
@@ -890,7 +888,7 @@ PHP_FUNCTION(libvirt_storagevolume_delete)
     retval = virStorageVolDelete(volume->volume, flags);
     DPRINTF("%s: virStorageVolDelete(%p, %d) returned %d\n", PHPFUNC, volume->volume, (int) flags, retval);
     if (retval != 0) {
-        set_error_if_unset("Cannot delete storage volume" TSRMLS_CC);
+        set_error_if_unset("Cannot delete storage volume");
         RETURN_FALSE;
     }
 
@@ -919,7 +917,7 @@ PHP_FUNCTION(libvirt_storagevolume_download)
     zend_long length = 0;
     int retval = -1;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rr|lll", &zvolume, &zstream, &offset, &length, &flags) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "rr|lll", &zvolume, &zstream, &offset, &length, &flags) == FAILURE)
         RETURN_LONG(retval);
     VIRT_FETCH_RESOURCE(volume, php_libvirt_volume*, &zvolume, PHP_LIBVIRT_VOLUME_RES_NAME, le_libvirt_volume);
     if ((volume == NULL) || (volume->volume == NULL))
@@ -932,7 +930,7 @@ PHP_FUNCTION(libvirt_storagevolume_download)
     DPRINTF("%s: virStorageVolDownload(%p, %p, %d, %d, %d) returned %d\n", PHPFUNC, volume->volume, stream->stream, (int) offset, (int) length, (int) flags, retval);
 
     if (retval == -1) {
-        set_error("Cannot download from stream" TSRMLS_CC);
+        set_error("Cannot download from stream");
         RETURN_LONG(retval);
     }
 
@@ -961,7 +959,7 @@ PHP_FUNCTION(libvirt_storagevolume_upload)
     zend_long length = 0;
     int retval = -1;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rr|lll", &zvolume, &zstream, &offset, &length, &flags) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "rr|lll", &zvolume, &zstream, &offset, &length, &flags) == FAILURE)
         RETURN_LONG(retval);
     VIRT_FETCH_RESOURCE(volume, php_libvirt_volume*, &zvolume, PHP_LIBVIRT_VOLUME_RES_NAME, le_libvirt_volume);
     if ((volume == NULL) || (volume->volume == NULL))
@@ -974,7 +972,7 @@ PHP_FUNCTION(libvirt_storagevolume_upload)
     DPRINTF("%s: virStorageVolUpload(%p, %p, %d, %d, %d) returned %d\n", PHPFUNC, volume->volume, stream->stream, (int) offset, (int) length, (int) flags, retval);
 
     if (retval == -1) {
-        set_error_if_unset("Cannot upload storage volume" TSRMLS_CC);
+        set_error_if_unset("Cannot upload storage volume");
         RETURN_LONG(retval);
     }
 
@@ -1003,7 +1001,7 @@ PHP_FUNCTION(libvirt_storagevolume_resize)
     retval = virStorageVolResize(volume->volume, capacity, flags);
     DPRINTF("%s: virStorageVolResize(%p, %d, %d) returned %d\n", PHPFUNC, volume->volume, (int) capacity, (int) flags, retval);
     if (retval != 0) {
-        set_error_if_unset("Cannot resize storage volume" TSRMLS_CC);
+        set_error_if_unset("Cannot resize storage volume");
         RETURN_LONG(retval);
     }
 
@@ -1035,7 +1033,6 @@ PHP_FUNCTION(libvirt_list_storagepools)
 
     array_init(return_value);
     for (i = 0; i < npools; i++) {
-        virStoragePoolPtr pool = pools[i];
         const char *name;
 
         if (!(name = virStoragePoolGetName(pools[i])))
@@ -1082,7 +1079,6 @@ PHP_FUNCTION(libvirt_list_active_storagepools)
 
     array_init(return_value);
     for (i = 0; i < npools; i++) {
-        virStoragePoolPtr pool = pools[i];
         const char *name;
 
         if (!(name = virStoragePoolGetName(pools[i])))
@@ -1129,7 +1125,6 @@ PHP_FUNCTION(libvirt_list_inactive_storagepools)
 
     array_init(return_value);
     for (i = 0; i < npools; i++) {
-        virStoragePoolPtr pool = pools[i];
         const char *name;
 
         if (!(name = virStoragePoolGetName(pools[i])))
